@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "elidinglabel.h"
 
@@ -58,7 +46,7 @@ QSize Palapeli::ElidingLabel::sizeHint() const
 void Palapeli::ElidingLabel::setFullText(const QString& text)
 {
 	m_fullText = text;
-	resizeEvent(0); //change text in label
+	resizeEvent(nullptr); //change text in label
 }
 
 void Palapeli::ElidingLabel::resizeEvent(QResizeEvent* event)
